:: GTA: Vice City - English to Japanese Converter
:: Created by zoton2. Other credits are in the README.

@echo off
title GTA: Vice City - English to Japanese Converter

:: Checks the batch file is being run as admin, otherwise throws an error.
mkdir "%windir%\system32\test" 2>nul
if "%errorlevel%" == "0" (rmdir "%windir%\system32\test") else (echo Please run this file as Administrator. & pause & exit)

:: Sets the current directory as the working one.
pushd %~dp0

:: Displays a message before everything else.
echo Welcome to the GTA: Vice City - English to Japanese Converter.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo This converts everything in such a way that your new copy will be identical to the Japanese copy (with a No-CD EXE).
PING 2.2.2.2 -n 1 -w 1000 >NUL
pause
cls
echo NOTE: This converter should work with most versions of the game that I know about.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo If it doesn't work for you, please contact me (see README.txt).
PING 2.2.2.2 -n 1 -w 1000 >NUL
pause
cls
GOTO CheckEXE

:: Checks if the EXE is in the directory.
:CheckEXE
IF EXIST gta-vc.exe GOTO CheckConversionFiles
IF NOT EXIST gta-vc.exe GOTO WrongDir
pause

:: Displays if it can't find the EXE from above.
:WrongDir
cls
echo Unable to find gta-vc.exe
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Please make sure these files are in the correct directory.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo This program will now exit.
pause
exit

:: Checks if the conversion files are there.
:: (Could be done a little better!)
:CheckConversionFiles
IF EXIST jp_cnvrt_files GOTO ConvertFiles
IF NOT EXIST jp_cnvrt_files GOTO NoConversionFiles
pause

:: If it can't find the conversion folder from above.
:NoConversionFiles
cls
echo Unable to find the conversion files directory (jp_cnvrt_files).
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Please make sure you copied this over along with this file.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo This program will now exit.
pause
exit

:: Does the actual conversion.
:ConvertFiles
:: Displays a message just before the conversion.
cls
echo Conversion commencing. Don't close this window until it is done.
PING 2.2.2.2 -n 1 -w 1000 >NUL
pause
cls

:: Removes read-only attributes from all files.
echo Removing read-only attributes from files.
attrib -r /s

:: Patches files that already exist.
echo Patching files.
for /F "tokens=*" %%A in (jp_cnvrt_files\files_to_patch.txt) do (
	ren %%A *.*.old
	jp_cnvrt_files\xdelta3.exe -d -f -s %%A.old jp_cnvrt_files\patches\%%A.xdelta %%A
	del %%A.old
)

:: Renames the readmes so they are correct.
ren readMe.txt ReadMe.txt
ren ReadMe\readMe.txt ReadMe.txt

:: Deletes files that don't exist in the Japanese version.
echo Deleting files that aren't in the Japanese version.
for /F "tokens=*" %%A in (jp_cnvrt_files\files_to_delete.txt) do (
	IF EXIST %%A del %%A
)

:: Copies files that are only in the Japanese version.
echo Copying over files that only exist in the Japanese version.
ROBOCOPY jp_cnvrt_files\extra_files .\ /E > NUL

:: Drop the .set file
:: Get Documents path from registry
@echo off
for /f "tokens=3*" %%p in ('REG QUERY "HKCU\Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders" /v Personal') do (
    set DocumentsFolder=%%p
)

:: Append \GTA Vice City User Files to get VC User Files root
set DocumentsFolder=%DocumentsFolder%\GTA Vice City User Files

:: Create dir if necessary
IF NOT EXIST "%DocumentsFolder%" (
	echo User Files folder not found, creating one..
	md "%DocumentsFolder%" >NUL
)

:: Move old set file if exists
IF EXIST "%DocumentsFolder%\gta_vc.set" (
	echo Set file found, renaming it to gta-vc.set.old
	move "%DocumentsFolder%\gta_vc.set" "%DocumentsFolder%\gta_vc.set.old" >NUL
)
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Dropping a default Japanese .set file into GTA Vice City User Files..
copy jp_cnvrt_files\gta_vc.set "%DocumentsFolder%\gta_vc.set" >NUL
PING 2.2.2.2 -n 1 -w 1000 >NUL

:: Checks the newly converted files to check they are exactly like the Japanese version.
echo Checking that the conversion was successful.
set /A incorrectFiles=0

for /F "tokens=*" %%A in (jp_cnvrt_files\files_to_check.txt) do (
	:: Gets the original hash.
	for /F "tokens=1 delims=," %%F in ("%%A") do (
		:: Gets the file location.
		for /F "tokens=2 delims=," %%G in ("%%A") do (
			:: Checks if the file to be checked actually exists.
			if exist "%%G" (
				:: Gets the hash of the converted files.
				for /F %%H in ('jp_cnvrt_files\md5.exe -n "%%G"') do (
					:: If both hashes aren't the same, increments the value.
					if %%F NEQ %%H set /A incorrectFiles+=1
				)
			) else (
				:: If the file doesn't exist, increments the value.
				set /A incorrectFiles+=1
			)
		)
	)
)

cls

if %incorrectFiles% == 0 (GOTO CompletedSuccessfully) else (GOTO ConversionCheckFailed)

:: If the converted files aren't exactly like the Japanese version.
:ConversionCheckFailed
echo The converted files were checked and are not exactly the same as the original Japanese files.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo %incorrectFiles% file(s) were not verified successfully.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Verify your game files through Steam and try again.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo This program will now exit.
pause
exit

:CompletedSuccessfully
:: Displays a message after all of this is done.
cls
echo Your copy of GTA: Vice City should now have been converted to the Japanese version.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Once this converter closes, the files used for the conversion will also be deleted.
PING 2.2.2.2 -n 1 -w 1000 >NUL
echo Launch gta-vc.exe to play!
pause

:: Deletes the converter files and then exits.
rmdir jp_cnvrt_files /q /s
start /b "" cmd /c del "%~f0"&exit /b
exit